'use strict';

const path = require('fire-path');
const fs = require('fire-fs');
const utils = Editor.require('packages://cocos-services/panel/utils/utils.js');
const ProjHelper = Editor.require(
    'packages://cocos-services/panel/utils/projHelper.js');
var projHelper;

module.exports = {
  load() {
    // 当 package 被正确加载的时候执行
    Editor.log('fast-compile扩展启动');
    // 当构建结束后会执行该事件
    Editor.Builder.on('before-change-files', (options, callback) => {
      this.onBuildedProjectEnable(options)
      callback();
    });

  },

  unload() {
    Editor.log('fast-compile扩展卸载');
  },

  onBuildedProjectEnable(options, params) {
    projHelper = new ProjHelper(options);
    projHelper.Android.androidPath = path.join(options.dest,
        `frameworks/runtime-src/proj.android-studio`);

    if (options.platform === 'android') {
      this.parseNative(options);
    }
  },

  parseNative(options, params) {
    var runtimePath = path.join(options.dest, 'frameworks/runtime-src');
    var list = [];
    // 把已经编译好的各个平台的so文件拷贝到proj.android-studio/app/libs目录下
    list.push({
      src: __dirname + '/armeabi-v7a',
      dst: path.join(runtimePath, 'proj.android-studio/app/libs/armeabi-v7a'),
    });

    utils.copyServicePackages(list);
    this.modifyGradle(options);
  },

  // 修改gradle.properties文件
  modifyGradle(options) {
    var runtimePath = path.join(options.dest, 'frameworks/runtime-src');
    let gradlePath = path.join(runtimePath, 'proj.android-studio/gradle.properties');
    if (!fs.existsSync(gradlePath)) return;
    let contents = fs.readFileSync(gradlePath, 'utf8');
    // 在后面追加PROP_NDK_MODE=none
    contents += '\nPROP_NDK_MODE=none';
    // 写入gradle.properties文件
    fs.writeFileSync(gradlePath, contents);
    Editor.log('修改gradle.properties文件成功');
  }
};